@@ -765,7 +765,8 @@ sub _can_write {
     if (
         eval '$>' and lc(`sudo -V`) =~ /version/ and _prompt(
             qq(
-==> Should we try to re-execute the autoinstall process with 'sudo'?), 'y'
+==> Should we try to re-execute the autoinstall process with 'sudo'?),
+            ((-t STDIN) ? 'y' : 'n')
         ) =~ /^[Yy]/
       )
     {
