@@ -1,9 +1,16 @@
 package Module::Install;
+
 use 5.004;
+use strict 'vars';
+use vars qw{$VERSION};
+BEGIN {
+	# Don't forget to update Module::Install::Admin too!
+	$VERSION = '0.51';
+}
 
-$VERSION = '0.50'; # Don't forget to update Module::Install::Admin too!
-
-die << "." unless $INC{join('/', inc => split(/::/, __PACKAGE__)).'.pm'};
+# inc::Module::Install must be loaded first
+unless ( $INC{join('/', inc => split(/::/, __PACKAGE__)).'.pm'} ) {
+	die <<"END_DIE";
 Please invoke ${\__PACKAGE__} with:
 
     use inc::${\__PACKAGE__};
@@ -12,28 +19,28 @@ not:
 
     use ${\__PACKAGE__};
 
-.
+END_DIE
+}
 
-use strict 'vars';
-use Cwd qw(cwd abs_path);
+use Cwd        ();
 use FindBin;
 use File::Find ();
 use File::Path ();
 
-@inc::Module::Install::ISA = 'Module::Install';
 *inc::Module::Install::VERSION = *VERSION;
+@inc::Module::Install::ISA     = 'Module::Install';
 
 sub autoload {
     my $self   = shift;
     my $caller = $self->_caller;
-
-    my $cwd = cwd();
-    my $sym = "$caller\::AUTOLOAD";
+    my $cwd    = Cwd::cwd();
+    my $sym    = "$caller\::AUTOLOAD";
 
     $sym->{$cwd} = sub {
-        my $pwd = cwd();
-        if (my $code = $sym->{$pwd}) {
-            goto &$code unless $cwd eq $pwd; # delegate back to parent dirs
+        my $pwd = Cwd::cwd();
+        if ( my $code = $sym->{$pwd} ) {
+        	# delegate back to parent dirs
+            goto &$code unless $cwd eq $pwd;
         }
         $$sym =~ /([^:]+)$/ or die "Cannot autoload $caller - $sym";
         unshift @_, ($self, $1);
@@ -43,9 +50,9 @@ sub autoload {
 
 sub import {
     my $class = shift;
-    my $self = $class->new(@_);
+    my $self  = $class->new(@_);
 
-    if (not -f $self->{file}) {
+    unless ( -f $self->{file} ) {
         require "$self->{path}/$self->{dispatch}.pm";
         File::Path::mkpath("$self->{prefix}/$self->{author}");
         $self->{admin} = 
@@ -66,19 +73,20 @@ sub import {
 sub preload {
     my ($self) = @_;
 
-    $self->load_extensions(
-        "$self->{prefix}/$self->{path}", $self
-    ) unless $self->{extensions};
+	unless ( $self->{extentions} ) {
+		$self->load_extensions(
+			"$self->{prefix}/$self->{path}", $self
+			);
+	}
 
     my @exts = @{$self->{extensions}};
-
-    unless (@exts) {
+    unless ( @exts ) {
         my $admin = $self->{admin};
         @exts = $admin->load_all_extensions;
     }
 
     my %seen_method;
-    foreach my $obj (@exts) {
+    foreach my $obj ( @exts ) {
         while (my ($method, $glob) = each %{ref($obj) . '::'}) {
             next unless defined *{$glob}{CODE};
             next if $method =~ /^_/;
@@ -100,8 +108,10 @@ sub new {
     my ($class, %args) = @_;
 
     # ignore the prefix on extension modules built from top level.
-    my $base_path = abs_path($FindBin::Bin);
-    delete $args{prefix} unless abs_path(cwd()) eq $base_path;
+    my $base_path = Cwd::abs_path($FindBin::Bin);
+    unless ( Cwd::abs_path(Cwd::cwd()) eq $base_path ) {
+    	delete $args{prefix};
+    }
 
     return $args{_self} if $args{_self};
 
@@ -144,10 +154,10 @@ sub load {
         return $obj if $obj->can($method);
     }
 
-    my $admin = $self->{admin} or die << "END";
+    my $admin = $self->{admin} or die <<"END_DIE";
 The '$method' method does not exist in the '$self->{prefix}' path!
 Please remove the '$self->{prefix}' directory and run $0 again to load it.
-END
+END_DIE
 
     my $obj = $admin->load($method, 1);
     push @{$self->{extensions}}, $obj;
@@ -168,7 +178,10 @@ sub load_extensions {
 
         local $@;
         my $new = eval { require $file; $pkg->can('new') };
-        if (!$new) { warn $@ if $@; next; }
+        unless ( $new ) {
+        	warn $@ if $@;
+        	next;
+        }
         $self->{pathnames}{$pkg} = delete $INC{$file};
         push @{$self->{extensions}}, &{$new}($pkg, _top => $top_obj );
     }
@@ -178,23 +191,23 @@ sub load_extensions {
 
 sub find_extensions {
     my ($self, $path) = @_;
-    my @found;
 
-    File::Find::find(sub {
+    my @found;
+    File::Find::find( sub {
         my $file = $File::Find::name;
         return unless $file =~ m!^\Q$path\E/(.+)\.pm\Z!is;
         return if $1 eq $self->{dispatch};
 
         $file = "$self->{path}/$1.pm";
         my $pkg = "$self->{name}::$1"; $pkg =~ s!/!::!g;
-        push @found, [$file, $pkg];
-    }, $path) if -d $path;
+        push @found, [ $file, $pkg ];
+    }, $path ) if -d $path;
 
     @found;
 }
 
 sub _caller {
-    my $depth = 0;
+    my $depth  = 0;
     my $caller = caller($depth);
 
     while ($caller eq __PACKAGE__) {
